ViewState<T extends StatefulView<VM>, VM extends ViewModel> class abstract

Mixed-in types

Constructors

ViewState()

Properties

context BuildContext
The location in the tree where this widget builds.
no setter
hashCode int
The hash code for this object.
no setterinherited
mounted bool
Whether this State object is currently in a tree.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vm → VM
no setter

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Called when a dependency of this State object changes.
override
didUpdateWidget(covariant T oldWidget) → void
Called whenever the widget configuration changes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited