mounted property

bool get mounted

Whether this State object is currently in a tree.

After creating a State object and before calling _initState, the framework "mounts" the State object by associating it with a BuildContext. The State object remains mounted until the framework calls _dispose, after which time the framework will never ask the State object to build again.

It is an error to call setState unless mounted is true.

Implementation

bool get mounted => _element != null;