reassemble method
Called whenever the application is reassembled during debugging, for example during hot reload. Most cases therefore do not need to do anything in the reassemble method.
See also:
Implementation
@protected
@mustCallSuper
@visibleForTesting
void reassemble() {
log('ViewModel<$runtimeType> reassemble');
}